;; Generated package description from moe-theme.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "moe-theme" "1.1.0.0.20260819.13" "A colorful eye-candy theme. Moe, moe, kyun!" 'nil :commit "6a5c85c89855ff1fba6aa57d68346b9b7bb7cec0" :authors '(("kuanyui" . "azazabc123@gmail.com")) :maintainer '("kuanyui" . "azazabc123@gmail.com") :keywords '("themes") :url "https://github.com/kuanyui/moe-theme.el")
